@@ -28,7 +28,8 @@
 #include "InternalUtils.hpp"
 #include <Diluculum/LuaUtils.hpp>
 #include <cstring>
-#include <boost/lexical_cast.hpp>
+#include <boost/scoped_array.hpp>
+
 
 namespace Diluculum
 {
