@@ -22,9 +22,7 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 
 namespace highlight
 {
-/** states which may occour during input file parsing
-    TODO Clean up!
-*/
+/** states which may occur during input file parsing */
 enum State {
     STANDARD=0,
     STRING,
@@ -37,6 +35,8 @@ enum State {
     LINENUMBER,
     SYMBOL,
     STRING_INTERPOLATION,
+    SYNTAX_ERROR,
+    SYNTAX_ERROR_MSG,
 
     // don't use constants > KEYWORD as array indices!
     KEYWORD,
@@ -58,7 +58,8 @@ enum State {
     _REJECT,
     _EOL,
     _EOF,
-    _WS
+    _WS,
+    _TESTPOS
 } ;
 
 /** Parser return values*/
@@ -85,6 +86,14 @@ enum LoadResult {
     LOAD_FAILED_LUA
 };
 
+/** language server initialization results*/
+enum LSResult {
+    INIT_OK,
+    INIT_BAD_PIPE,
+    INIT_BAD_REQUEST,
+    CMD_ERROR
+};
+
 /** output formats */
 enum OutputType {
     HTML,
@@ -94,12 +103,11 @@ enum OutputType {
     RTF,
     ESC_ANSI,
     ESC_XTERM256,
-    HTML32_UNUSED,
+    ESC_TRUECOLOR,
     SVG,
     BBCODE,
     PANGO,
-    ODTFLAT,
-    ESC_TRUECOLOR
+    ODTFLAT
 };
 
 }
